**********************************************************************************************************************************************************
**********************************************************************************************************************************************************
* Do file for:
* Prorok, Alyssa. 2016. "Led Astray: Leaders and the Duration of Civil War." 
* Journal of Conflict Resolution
**********************************************************************************************************************************************************
**********************************************************************************************************************************************************

clear
use "AProrok_JCR.dta", clear
set more off
stset count, id(dyadepid) failure(terminate)


*************************************************************
* code to reproduce models 1, 2, & 3 in Table 1 (MAIN TEXT):
*************************************************************
* Model 1:
stcox culpbdep_dum ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 2: 
stcox culpbdep_dum_reb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 3: 
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)


*************************************************
* code to reproduce Figure 1 (MAIN TEXT):
*************************************************
qui stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
#delimit;
stcurve, survival 
  at1(culpbdep_dum_reb=0 culphighriskst=0 culplowriskst=1 ldrchange_reb3=0 ldrchange_st3=0 stmilsupportex=1 effterrcontm=0) 
  at2(culpbdep_dum_reb=1 culphighriskst=0 culplowriskst=1 ldrchange_reb3=0 ldrchange_st3=0 stmilsupportex=1 effterrcontm=0) 
  xscale(range(0 576)) xlabel(0 (48) 576, labsize(small)) 
  ytitle("Probability of Survival" " ") 
  ylabel(0 (.1) 1, val angle(horizontal) labsize(small)) 
  xtitle(" " "Conflict Duration (Months)", size(small)) 
  title(Rebel Responsibility, size(medlarge)) 
  clwidth(medthick medthick) clpattern(solid "--") clcolor(gs10 gs5) 
  graphregion(color(white))   
  subtitle( , size(vsmall)) 
  legend(size(small) region(lcolor(white)) label(1 "Non-Responsible") label(2 "Responsible"))
  saving(scurvem3reb.gph, replace)
  ;
#delimit cr

#delimit;
stcurve, survival 
  at1(culpbdep_dum_reb=1 culphighriskst=0 culplowriskst=0 ldrchange_reb3=0 ldrchange_st3=0 stmilsupportex=1 effterrcontm=0) 
  at2(culpbdep_dum_reb=1 culphighriskst=0 culplowriskst=1 ldrchange_reb3=0 ldrchange_st3=0 stmilsupportex=1 effterrcontm=0) 
  at3(culpbdep_dum_reb=1 culphighriskst=1 culplowriskst=0 ldrchange_reb3=0 ldrchange_st3=0 stmilsupportex=1 effterrcontm=0) 
  xscale(range(0 576)) xlabel(0 (48) 576, labsize(small)) 
  ytitle("Probability of Survival" " ") 
  ylabel(0 (.1) 1, val angle(horizontal) labsize(small)) 
  xtitle(" " "Conflict Duration (Months)", size(small)) 
  title(State Responsibility, size(medlarge)) 
  clwidth(medthick medthick) clpattern(solid shortdash longdash) clcolor(gs10 gs5 black) 
  graphregion(color(white))   
  subtitle( , size(vsmall)) 
  legend(size(small) region(lcolor(white)) label(1 "Non-Responsible") label(2 "Responsible Low Risk") label(3 "Responsible High Risk"))
  saving(scurvem3st.gph, replace)
  ;
#delimit cr

#delimit;
graph combine scurvem3reb.gph scurvem3st.gph ,
  col(2)
  title("Figure 1: Conflict Survival by Leader Responsibility (Model 3)", size(med))
  subtitle("", size(medsmall))
  graphregion(color(white))
  ;
#delimit cr





**************************************************************
**************************************************************
* Code to replicate all analyses in the Online Supplement
**************************************************************
**************************************************************


****************
* Table S1:
****************
* Model 1:
stcox culphighriskreb culplowriskreb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex muchweakerdum strongerdum lnnumofdyads effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc, cluster(dyadepid)
* Model 2:
stcox culpstbothrisk culpstinternalriskonly culpstexternalriskonly culpstnorisk culprebbothrisk culprebinternalriskonly culprebexternalriskonly culprebnorisk ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop , cluster(dyadepid) 


****************
* Table S2:
****************
* Model 1:
stcox culpbdep_dumesc ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 2:
stcox culpbdep_dumsp ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 3:
stcox culpbdep_dum_rebesc culpbdep_dum_stesc ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 4:
stcox culpbdep_dum_reb culpbdepst_sameparty ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
* Model 5:
stcox culpbdep_dum_rebesc culpeschighriskst culpesclowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid)
* Model 6:
stcox culpbdep_dum_reb culphighriskstb culplowriskstb ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid)


****************
* Table S3:
****************
* Model 1:
stcox culpreb_sqpoor culpreb_favorable culpst_sqpoor culpst_favorable ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
* Model 2:
stcox culpreb_sqpoornc culpreb_favorablenc culpst_sqpoornc culpst_favorablenc ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 3:
stcox culpreb_sqpoor culpreb_favorable culpst_sqpoor_highrisk culpst_sqpoor_lowrisk culpst_favorable ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop culpst_favorabletvc effterrcontmtvc, cluster(dyadepid) 
* Model 4:
stcox culpreb_sqpoornc culpreb_favorablenc culpst_sqpoornc_highrisk culpst_sqpoornc_lowrisk culpst_favorablenc ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop culpst_favorablenctvc, cluster(dyadepid) 


****************
* Table S4:
****************
clear
use AProrok_JCR_tableS4.dta
* Model 1:
logit punish_all culpbdep_dum lnbdbest lnldrconf_duration constlimit transitional_ldr muchweakerdum strongerdum , cluster(actorid)
* Model 2:
logit punish_all culpst_highrisk culpst_lowrisk lnbdbest lnldrconf_duration constlimit transitional_ldr , cluster(actorid)
* Model 3:
logit punish_all culpst_sqpoor_highrisk culpst_sqpoor_lowrisk culpst_favor_highrisk culpst_favor_lowrisk lnbdbest lnldrconf_duration constlimit transitional_ldr , cluster(actorid)


****************
* Table S5:
****************
clear
use AProrok_JCR_tableS5.dta
* Model 1:
logit punish_all culpbdep_dum lnbdbest lnldrconf_duration locationdum muchweakerdum strongerdum , cluster(actorid) 
* Model 2:
logit punish_all culphighriskreb culplowriskreb lnbdbest lnldrconf_duration muchweakerdum strongerdum , cluster(actorid) 
* Model 3:
logit punish_all culpreb_sqpoor culpreb_favor lnbdbest lnldrconf_duration locationdum muchweakerdum strongerdum , cluster(actorid) 


****************
* Table S6:
****************
clear
use "AProrok_JCR_tableS6.dta", clear

* Model 1:
relogit ldrchange_nonculp2 lnivb_lag count count2 count3, cluster(dyadid)
* Model 2:
relogit ldrchange_nonculp2 lnivb_lag count count2 count3 if stldr==1, cluster(dyadid)
* Model 3:
relogit ldrchange_nonculp2 lnivb_lag count count2 count3 if rebldr==1, cluster(dyadid)
* Model 4:
relogit ldrchange_nonculp2 lniva_lag count count2 count3, cluster(dyadid)
* Model 5:
relogit ldrchange_nonculp2 lniva_lag count count2 count3 if stldr==1, cluster(dyadid)
* Model 6:
relogit ldrchange_nonculp2 lniva_lag count count2 count3 if rebldr==1, cluster(dyadid)


****************
* Table S7:
****************
clear
use "AProrok_JCR.dta", clear
* Column 1:
stset count, id(dyadepid) failure(settleorlow2==1)
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid)
* Column 2:
stset count, id(dyadepid) failure(settleorlow2==2)
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads lnrgdppc lnpop effterrcontm culplowrisksttvc ldrchange_st3tvc stmilsupportextvc lnnumofdyadstvc lnrgdppctvcln, cluster(dyadepid) 


****************
* Table S8:
****************
stset count, id(dyadepid) failure(terminate)
* Model 1:
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb ldrchange_st stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 2:
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb6 ldrchange_st6 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 3: 
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb9 ldrchange_st9 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop ldrchange_st9tvc effterrcontmtvc, cluster(dyadepid) 
* Model 4:
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb12 ldrchange_st12 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid)
* Model 5:
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb18 ldrchange_st18 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop ldrchange_st18tvc effterrcontmtvc, cluster(dyadepid)
* Model 6:
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb24 ldrchange_st24 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop ldrchange_st24tvc effterrcontmtvc, cluster(dyadepid)


****************
* Table S9:
****************
* Model 1:
stcox culpbdep_dum ldrchange_reb3 ldrchange_st3 externalw_reb externalf_reb externalx_reb externalw_st externalf_st externalx_st lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 2:
stcox culpbdep_dum ldrchange_reb3 ldrchange_st3 externalw_reb3 externalf_reb3 externalx_reb externalw_st3 externalf_st3 externalx_st lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 3:
stcox culpbdep_dum_reb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 externalw_reb externalf_reb externalx_reb externalw_st externalf_st externalx_st lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid) 
* Model 4:
stcox culpbdep_dum_reb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 externalw_reb3 externalf_reb3 externalx_reb externalw_st3 externalf_st3 externalx_st lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop effterrcontmtvc, cluster(dyadepid)


****************
* Table S10:
****************
* Model 1
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc if ldrnum_st>1 | ldrnum_reb>1 , cluster(dyadepid) 
* Model 2
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop SDIAP_C oilp_C effterrcontmtvc SDIAP_Ctvc lnrgdppctvcln, cluster(dyadepid)
* Model 3
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads lnrgdppc lnpop terrcont2 rebpolwinglegal2, cluster(dyadepid) 
* Model 4
stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc if coup!=1, cluster(dyadepid) 


****************
* Table S11:
****************
qui stcox culpbdep_dum ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
qui estpost correlate culpbdep_dum ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc if e(sample), matrix
esttab , b(2) label unstack nostar not noobs compress replace title(Table X: Correlation Matrix for Model 1)


****************
* Table S12:
****************
qui stcox culpbdep_dum_reb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc , cluster(dyadepid) 
qui estpost correlate culpbdep_dum_reb culpbdep_dum_st ldrchange_reb3 ldrchange_st3 rebmilsupportex stmilsupportex lnnumofdyads muchweakerdum strongerdum effterrcontm demdum7 lnrgdppc lnpop rebmilsupportextvc effterrcontmtvc if e(sample), matrix
esttab , b(2) label unstack nostar not noobs compress replace title(Table X: Correlation Matrix for Model 2)


****************
* Table S13:
****************
qui stcox culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
qui estpost correlate culpbdep_dum_reb culphighriskst culplowriskst ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc if e(sample), matrix
esttab , b(2) label unstack nostar not noobs compress replace title(Table X: Correlation Matrix for Model 3)


****************
* Figure S1:
****************
stcox culphighriskst culplowriskst culpbdep_dum_reb ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
predict S03, basesurv 
sum S03
gen S13_ns=S03^exp(_b[culphighriskst]*0 + _b[culplowriskst]*0 + _b[culpbdep_dum_reb]*culpbdep_dum_reb + _b[ldrchange_reb3]*ldrchange_reb3 + _b[ldrchange_st3]*ldrchange_st3 + _b[stmilsupportex]*stmilsupportex + _b[lnnumofdyads]*lnnumofdyads + _b[effterrcontm]*effterrcontm + _b[lnrgdppc]*lnrgdppc + _b[lnpop]*lnpop + _b[effterrcontmtvc]*effterrcontmtvc) if e(sample)
gen S13_hs=S03^exp(_b[culphighriskst]*1 + _b[culplowriskst]*0 + _b[culpbdep_dum_reb]*culpbdep_dum_reb + _b[ldrchange_reb3]*ldrchange_reb3 + _b[ldrchange_st3]*ldrchange_st3 + _b[stmilsupportex]*stmilsupportex + _b[lnnumofdyads]*lnnumofdyads + _b[effterrcontm]*effterrcontm + _b[lnrgdppc]*lnrgdppc + _b[lnpop]*lnpop + _b[effterrcontmtvc]*effterrcontmtvc) if e(sample)
gen S13_ls=S03^exp(_b[culphighriskst]*0 + _b[culplowriskst]*1 + _b[culpbdep_dum_reb]*culpbdep_dum_reb + _b[ldrchange_reb3]*ldrchange_reb3 + _b[ldrchange_st3]*ldrchange_st3 + _b[stmilsupportex]*stmilsupportex + _b[lnnumofdyads]*lnnumofdyads + _b[effterrcontm]*effterrcontm + _b[lnrgdppc]*lnrgdppc + _b[lnpop]*lnpop + _b[effterrcontmtvc]*effterrcontmtvc) if e(sample)
gen S13_nr=S03^exp(_b[culphighriskst]*culphighriskst+ _b[culplowriskst]*culplowriskst + _b[culpbdep_dum_reb]*0 + _b[ldrchange_reb3]*ldrchange_reb3 + _b[ldrchange_st3]*ldrchange_st3 + _b[stmilsupportex]*stmilsupportex + _b[lnnumofdyads]*lnnumofdyads + _b[effterrcontm]*effterrcontm + _b[lnrgdppc]*lnrgdppc + _b[lnpop]*lnpop + _b[effterrcontmtvc]*effterrcontmtvc) if e(sample)
gen S13_rr=S03^exp(_b[culphighriskst]*culphighriskst+ _b[culplowriskst]*culplowriskst + _b[culpbdep_dum_reb]*1 + _b[ldrchange_reb3]*ldrchange_reb3 + _b[ldrchange_st3]*ldrchange_st3 + _b[stmilsupportex]*stmilsupportex + _b[lnnumofdyads]*lnnumofdyads + _b[effterrcontm]*effterrcontm + _b[lnrgdppc]*lnrgdppc + _b[lnpop]*lnpop + _b[effterrcontmtvc]*effterrcontmtvc) if e(sample)
sum S13_ns S13_hs S13_ls S13_nr S13_rr
collapse (mean) S13_ns S13_hs S13_ls S13_nr S13_rr, by(_t)

line S13_nr S13_rr _t if _t<210, connect(J J) sort ///
  xscale(range(0 210)) xlabel(0 (48) 210, labsize(small)) ///
  ytitle("Probability of Survival" " ") ///
  ylabel(0 (.1) 1, val angle(horizontal) labsize(small)) ///
  xtitle(" " "Conflict Duration (Months)", size(small)) ///
  title(Rebel Responsibility, size(medlarge)) ///
  clwidth(medthick medthick) clpattern(solid dash) clcolor(gs10 gs5) ///
  graphregion(color(white)) ///  
  subtitle( , size(vsmall)) ///
  legend(size(small) region(lcolor(white)) label(1 "Non-Responsible") label(2 "Responsible")) ///
  saving(scurvem3reb_ov.gph, replace)
 
line S13_ns S13_hs S13_ls _t if _t<210, connect(J J) sort ///
  xscale(range(0 210)) xlabel(0 (48) 210, labsize(small)) ///
  ytitle("Probability of Survival" " ") ///
  ylabel(0 (.1) 1, val angle(horizontal) labsize(small)) ///
  xtitle(" " "Conflict Duration (Months)", size(small)) ///
  title(State Responsibility, size(medlarge)) ///
  clwidth(medthick medthick) clpattern(solid shortdash longdash) clcolor(gs10 gs5 black) ///
  graphregion(color(white)) ///  
  subtitle( , size(vsmall)) ///
  legend(size(small) region(lcolor(white)) label(1 "Non-Responsible") label(2 "Responsible Low Risk") label(3 "Responsible High Risk")) ///
  saving(scurvem3st_ov.gph, replace)

#delimit;
graph combine scurvem3reb_ov.gph scurvem3st_ov.gph,
  col(2)
  title("Figure S1: Conflict Survival (Model 3)", size(med))
  subtitle("", size(medsmall))
  graphregion(color(white))
  note("Note: Controls held at observed values, results based on Model 3.", size(small)) ///
  ;
#delimit cr


****************
* Figure S2:
****************
clear
use "AProrok_JCR.dta", clear
stset count, id(dyadepid) failure(terminate)

qui stcox culphighriskst culplowriskst culpbdep_dum_reb ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
predict S0m, basesurv 
qui stcox culphighriskst culplowriskst culpbdep_dum_reb ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
qui margins if countcat12<18, dydx(culpbdep_dum_reb) over(countcat12) expression(S0m^exp(predict(xb))) 
marginsplot, yline(0) /// 
  recast(scatter) recastci(rspike) ///
  xlabel(0(5)15) ///
  xmtick(0(1)17) ///
  ytitle(Change in Probability of Survival) ///
  xtitle(Analysis Time (Years)) ///
  title(Rebel Responsibility, size(medlarge)) ///
  legend(off) ///
  graphregion(color(white)) ///
  note(Baseline: Non-Responsible Rebel Leader) ///
  saving(fdm3reb_ov.gph, replace)

qui stcox culphighriskst culplowriskst culpbdep_dum_reb ldrchange_reb3 ldrchange_st3 stmilsupportex lnnumofdyads effterrcontm lnrgdppc lnpop effterrcontmtvc , cluster(dyadepid)
qui margins if countcat12<18, dydx(culphighriskst) over(countcat12) expression(S0m^exp(predict(xb))) 
marginsplot, yline(0) /// 
  recast(scatter) recastci(rspike) ///
  xlabel(0(5)15) ///
  xmtick(0(1)17) ///
  ytitle(Change in Probability of Survival) ///
  xtitle(Analysis Time (Years)) ///
  title(High Risk State Responsibility, size(medlarge)) ///
  legend(off) ///
  graphregion(color(white)) ///
  note(Baseline: Non-Responsible State Leader) ///
  saving(fdm3sthr_ov.gph, replace)

#delimit;
graph combine fdm3reb_ov.gph fdm3sthr_ov.gph,
  col(2)
  title("Figure S2: Change in Pr(Survival)", size(med))
  subtitle("", size(medsmall))
  graphregion(color(white))
  note("Note: Controls held at observed values, results based on Model 3.", size(small)) ///
  ;
#delimit cr





